==> CloudClientStandardAWS_v2.0.0.zip: com/clustercontrol/ws/cloud/ModifyAccountResourceRequest.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>modifyAccountResourceRequest complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="modifyAccountResourceRequest">
 *   &lt;complexContent>
 *     &lt;extension base="{http://cloud.ws.clustercontrol.com}cloudRequest">
 *       &lt;sequence>
 *         &lt;element name="accountResourceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="accountResourceName" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "modifyAccountResourceRequest", propOrder = {
    "accountResourceId",
    "accountResourceName",
    "description"
})
public class ModifyAccountResourceRequest
    extends CloudRequest
{

    protected String accountResourceId;
    protected String accountResourceName;
    protected String description;

    /**
     * accountResourceIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccountResourceId() {
        return accountResourceId;
    }

    /**
     * accountResourceIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccountResourceId(String value) {
        this.accountResourceId = value;
    }

    /**
     * accountResourceNameプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccountResourceName() {
        return accountResourceName;
    }

    /**
     * accountResourceNameプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccountResourceName(String value) {
        this.accountResourceName = value;
    }

    /**
     * descriptionプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * descriptionプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

}

==> CloudClientStandardAWS_v2.0.1.zip: com/clustercontrol/ws/cloud/ModifyAccountResourceRequest.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>modifyAccountResourceRequest complex typeJavaNXB
 * 
 * <p>̃XL[}EtOǵÃNXɊ܂܂\Recw肵܂B
 * 
 * <pre>
 * &lt;complexType name="modifyAccountResourceRequest">
 *   &lt;complexContent>
 *     &lt;extension base="{http://cloud.ws.clustercontrol.com}cloudRequest">
 *       &lt;sequence>
 *         &lt;element name="accountResourceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="accountResourceName" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "modifyAccountResourceRequest", propOrder = {
    "accountResourceId",
    "accountResourceName",
    "description"
})
public class ModifyAccountResourceRequest
    extends CloudRequest
{

    protected String accountResourceId;
    protected String accountResourceName;
    protected String description;

    /**
     * accountResourceIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccountResourceId() {
        return accountResourceId;
    }

    /**
     * accountResourceIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccountResourceId(String value) {
        this.accountResourceId = value;
    }

    /**
     * accountResourceNamevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccountResourceName() {
        return accountResourceName;
    }

    /**
     * accountResourceNamevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccountResourceName(String value) {
        this.accountResourceName = value;
    }

    /**
     * descriptionvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * descriptionvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

}
